@@ -1,14 +1,16 @@
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
+
 from http import HTTPStatus
 from typing import Any, Iterable  # noqa: F401
 
-from flask_restful import Resource, reqparse
 from flasgger import swag_from
+from flask_restful import Resource, reqparse
 
 from search_service.api.base import BaseFilterAPI
 from search_service.models.table import SearchTableResultSchema
 from search_service.proxy import get_proxy_client
 
-
 TABLE_INDEX = 'table_search_index'
 
 
@@ -46,7 +48,7 @@ class SearchTableAPI(Resource):
                 index=args.get('index')
             )
 
-            return SearchTableResultSchema().dump(results).data, HTTPStatus.OK
+            return SearchTableResultSchema().dump(results), HTTPStatus.OK
 
         except RuntimeError:
 
@@ -58,6 +60,7 @@ class SearchTableFilterAPI(BaseFilterAPI):
     """
     Search Filter for table
     """
+
     def __init__(self) -> None:
         super().__init__(schema=SearchTableResultSchema,
                          index=TABLE_INDEX)
