@@ -1,7 +1,11 @@
-from typing import Set
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
+
+from typing import List, Set
 
 import attr
 from amundsen_common.models.dashboard import DashboardSummary, DashboardSummarySchema
+from marshmallow3_annotations.ext.attrs import AttrsSchema
 
 from search_service.models.base import Base
 
@@ -12,14 +16,16 @@ class Dashboard(Base,
     """
     This represents the part of a dashboard stored in the search proxy
     """
+    id: str = attr.ib()
 
     def get_id(self) -> str:
         # uses the table key as the document id in ES
-        return self.name
+        return self.id
 
     @classmethod
     def get_attrs(cls) -> Set:
         return {
+            'id',
             'uri',
             'cluster',
             'group_name',
@@ -40,3 +46,15 @@ class DashboardSchema(DashboardSummarySchema):
     class Meta:
         target = Dashboard
         register_as_scheme = True
+
+
+@attr.s(auto_attribs=True, kw_only=True)
+class SearchDashboardResult:
+    total_results: int = attr.ib()
+    results: List[Dashboard] = attr.ib(factory=list)
+
+
+class SearchDashboardResultSchema(AttrsSchema):
+    class Meta:
+        target = SearchDashboardResult
+        register_as_scheme = True
