@@ -6,10 +6,14 @@ from typing import (
     Any, Dict, List, Union,
 )
 
+from amundsen_common.models.api.health_check import HealthCheck
+from amundsen_common.models.search import Filter, SearchResponse
+
 from search_service.models.dashboard import SearchDashboardResult
 from search_service.models.feature import SearchFeatureResult
 from search_service.models.table import SearchTableResult
 from search_service.models.user import SearchUserResult
+from search_service.proxy.es_search_proxy import Resource
 
 
 class BaseProxy(metaclass=ABCMeta):
@@ -18,6 +22,23 @@ class BaseProxy(metaclass=ABCMeta):
     the proxy clients available in the amundsen search service
     """
 
+    def health(self) -> HealthCheck:
+        """
+        Runs one or more series of checks on the service. Can also
+        optionally return additional metadata about each check (e.g.
+        latency to database, cpu utilization, etc.).
+        """
+        return HealthCheck(status='ok', checks={f'{type(self).__name__}:connection': {'status': 'not checked'}})
+
+    @abstractmethod
+    def search(self, *,
+               query_term: str,
+               page_index: int,
+               results_per_page: int,
+               resource_types: List[Resource],
+               filters: List[Filter]) -> SearchResponse:
+        pass
+
     @abstractmethod
     def fetch_table_search_results(self, *,
                                    query_term: str,
@@ -62,6 +83,23 @@ class BaseProxy(metaclass=ABCMeta):
                         index: str = '') -> str:
         pass
 
+    @abstractmethod
+    def update_document_by_key(self, *,
+                               resource_key: str,
+                               resource_type: Resource,
+                               field: str,
+                               value: str = None,
+                               operation: str = 'add') -> str:
+        pass
+
+    @abstractmethod
+    def delete_document_by_key(self, *,
+                               resource_key: str,
+                               resource_type: Resource,
+                               field: str,
+                               value: str = None) -> str:
+        pass
+
     @abstractmethod
     def create_document(self, *,
                         data: List[Dict[str, Any]],
