@@ -1,19 +1,21 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
 
-import itertools
 import logging
 import uuid
 from typing import (
     Any, Dict, List, Union,
 )
 
+from amundsen_common.models.api import health_check
 from amundsen_common.models.index_map import (
     FEATURE_INDEX_MAP, TABLE_INDEX_MAP, USER_INDEX_MAP,
 )
+from amundsen_common.models.search import Filter, SearchResponse
 from elasticsearch import Elasticsearch
-from elasticsearch.exceptions import NotFoundError
+from elasticsearch.exceptions import ConnectionError as ElasticConnectionError, NotFoundError
 from elasticsearch_dsl import Search, query
+from elasticsearch_dsl.utils import AttrDict
 from flask import current_app
 
 from search_service import config
@@ -28,6 +30,7 @@ from search_service.models.table import SearchTableResult, Table
 from search_service.models.tag import Tag
 from search_service.models.user import SearchUserResult, User
 from search_service.proxy.base import BaseProxy
+from search_service.proxy.es_search_proxy import Resource
 from search_service.proxy.statsd_utilities import timer_with_counter
 
 # Default Elasticsearch index to use, if none specified
@@ -42,6 +45,7 @@ class ElasticsearchProxy(BaseProxy):
     """
     # mapping to translate request for table resources
     TABLE_MAPPING = {
+        'key': 'key',
         'badges': 'badges',
         'tag': 'tags',
         'schema': 'schema.raw',
@@ -67,6 +71,7 @@ class ElasticsearchProxy(BaseProxy):
 
     # mapping to translate request for feature resources
     FEATURE_MAPPING = {
+        'key': 'key',
         'feature_group': 'feature_group.raw',
         'feature_name': 'feature_name.raw',
         'entity': 'entity',
@@ -77,6 +82,10 @@ class ElasticsearchProxy(BaseProxy):
         'badges': 'badges'
     }
 
+    # special characters we want to escape in filter values. See:
+    # https://www.elastic.co/guide/en/elasticsearch/reference/5.5/query-dsl-query-string-query.html#_reserved_characters
+    ESCAPE_CHARS = str.maketrans({':': r'\:', '/': r'\/'})
+
     def __init__(self, *,
                  host: str = None,
                  user: str = '',
@@ -103,6 +112,24 @@ class ElasticsearchProxy(BaseProxy):
 
         self.page_size = page_size
 
+    def health(self) -> health_check.HealthCheck:
+        """
+        Returns the health of the Elastic search cluster
+        """
+        try:
+            if self.elasticsearch.ping():
+                health = self.elasticsearch.cluster.health()
+                # ES status vaues: green, yellow, red
+                status = health_check.OK if health['status'] != 'red' else health_check.FAIL
+            else:
+                health = {'status': 'Unable to connect'}
+                status = health_check.FAIL
+            checks = {f'{type(self).__name__}:connection': health}
+        except ElasticConnectionError:
+            status = health_check.FAIL
+            checks = {f'{type(self).__name__}:connection': {'status': 'Unable to connect'}}
+        return health_check.HealthCheck(status=status, checks=checks)
+
     def get_user_search_query(self, query_term: str) -> dict:
         return {
             "function_score": {
@@ -279,7 +306,13 @@ class ElasticsearchProxy(BaseProxy):
             except Exception:
                 LOGGING.exception('The record doesnt contain specified field.')
 
-        return search_result_model(total_results=response.hits.total,
+        # This is to support ESv7.x, and newer version of elasticsearch_dsl
+        if isinstance(response.hits.total, AttrDict):
+            _total = response.hits.total.value
+        else:
+            _total = response.hits.total
+
+        return search_result_model(total_results=_total,
                                    results=results)
 
     def _get_instance(self, attr: str, val: Any) -> Any:
@@ -306,6 +339,9 @@ class ElasticsearchProxy(BaseProxy):
         :param query_name: name of query to query the ES
         :return:
         """
+        # This is to support ESv7.x
+        # ref: https://www.elastic.co/guide/en/elasticsearch/reference/7.0/breaking-changes-7.0.html#track-total-hits-10000-default # noqa: E501
+        client = client.extra(track_total_hits=True)
 
         if query_name:
             q = query.Q(query_name)
@@ -347,27 +383,14 @@ class ElasticsearchProxy(BaseProxy):
             elif item_list is '' or item_list == ['']:
                 LOGGING.warn(f'The filter value cannot be empty.In this case the filter {category} is ignored')
             else:
-                query_list.append(mapped_category + ':' + '(' + ' OR '.join(item_list) + ')')
+                escaped = [item.translate(cls.ESCAPE_CHARS) for item in item_list]
+                query_list.append(mapped_category + ':' + '(' + ' OR '.join(escaped) + ')')
 
         if len(query_list) == 0:
             return ''
 
         return ' AND '.join(query_list)
 
-    @staticmethod
-    def validate_filter_values(search_request: dict) -> Any:
-        if 'filters' in search_request:
-            filter_values_list = search_request['filters'].values()
-            # Ensure all values are arrays
-            filter_values_list = list(
-                map(lambda x: x if type(x) == list else [x], filter_values_list))
-            # Flatten the array of arrays
-            filter_values_list = list(itertools.chain.from_iterable(filter_values_list))
-            # Check if / or : exist in any of the values
-            if any(("/" in str(item) or ":" in str(item)) for item in (filter_values_list)):
-                return False
-            return True
-
     @staticmethod
     def parse_query_term(query_term: str,
                          index: str) -> str:
@@ -439,16 +462,10 @@ class ElasticsearchProxy(BaseProxy):
         add_query = ''
         query_dsl = ''
         if filter_list:
-            valid_filters = self.validate_filter_values(search_request)
-            if valid_filters is False:
-                raise Exception(
-                    'The search filters contain invalid characters and thus cannot be handled by ES')
-            query_dsl = self.parse_filters(filter_list,
-                                           index)
+            query_dsl = self.parse_filters(filter_list, index)
 
         if query_term:
-            add_query = self.parse_query_term(query_term,
-                                              index)
+            add_query = self.parse_query_term(query_term, index)
 
         if not query_dsl and not add_query:
             raise Exception('Unable to convert parameters to valid query dsl')
@@ -730,7 +747,7 @@ class ElasticsearchProxy(BaseProxy):
         return [{'delete': {'_index': index_key, '_id': id, '_type': type}} for id in data]
 
     def _bulk_helper(self, actions: List[Dict[str, Any]]) -> None:
-        result = self.elasticsearch.bulk(actions)
+        result = self.elasticsearch.bulk(body=actions)
 
         if result['errors']:
             # ES's error messages are nested within elasticsearch objects and can
@@ -746,7 +763,7 @@ class ElasticsearchProxy(BaseProxy):
         :return: list of elasticsearch indices
         """
         try:
-            indices = self.elasticsearch.indices.get_alias(alias).keys()
+            indices = self.elasticsearch.indices.get_alias(index=alias).keys()
             return indices
         except NotFoundError:
             LOGGING.warn('Received index not found error from Elasticsearch', exc_info=True)
@@ -771,5 +788,28 @@ class ElasticsearchProxy(BaseProxy):
 
         # alias our new index
         index_actions = {'actions': [{'add': {'index': index_key, 'alias': alias}}]}
-        self.elasticsearch.indices.update_aliases(index_actions)
+        self.elasticsearch.indices.update_aliases(body=index_actions)
         return index_key
+
+    def search(self, *,
+               query_term: str,
+               page_index: int,
+               results_per_page: int,
+               resource_types: List[Resource],
+               filters: List[Filter]) -> SearchResponse:
+        pass
+
+    def update_document_by_key(self, *,
+                               resource_key: str,
+                               resource_type: Resource,
+                               field: str,
+                               value: str = None,
+                               operation: str = 'add') -> str:
+        pass
+
+    def delete_document_by_key(self, *,
+                               resource_key: str,
+                               resource_type: Resource,
+                               field: str,
+                               value: str = None) -> str:
+        pass
